@@ -1,6 +1,6 @@
 /**************************************************************************
     Qalendar
-    Copyright (C) 2013 Grzegorz Gidel
+    Copyright (C) 2013-2014 Grzegorz Gidel
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,6 +26,8 @@
 
 #include "MainWindow.h"
 
+#include "Date.h"
+
 int main(int argc, char  *argv[])
 {
     QApplication::setOrganizationName("qalendar");
@@ -76,6 +78,8 @@ int main(int argc, char  *argv[])
 
     QLocale::setDefault(lang);
 
+    Date::init();
+
     MainWindow window(runInBackground);
 
     return app.exec();
