@@ -4,8 +4,6 @@
 #include "RotatingDialog.h"
 #include "ui_CalendarEditDialog.h"
 
-#include <QButtonGroup>
-
 #include "CCalendar.h"
 
 class CalendarEditDialog : public RotatingDialog
@@ -23,11 +21,11 @@ public:
 private:
     Ui::CalendarEditDialog *ui;
 
-    QButtonGroup *typeGroup;
-
     CCalendar *calendar;
 
 private slots:
+    void onTypeButtonClicked(int type);
+
     void saveCalendar();
     void exportCalendar();
     void deleteCalendar();
